#
# spec file for package gwenhywfar
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libversion 79
%define devversion 5
%define devrelease 5.12
# Beta does not mean "before release" but a release that is considered as beta:
%define _version %{version}
%define _name gwenhywfar
%define releasenumber 529
%define checksumreleasenumber 528
%bcond_with configure
Name:           gwenhywfar
Version:        5.12.0
Release:        2.1
Summary:        Multiplatform helper library for other libraries
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/Libraries
URL:            https://www.aquamaniac.de/rdm/projects/gwenhywfar
Source:         https://www.aquamaniac.de/rdm/attachments/download/%{releasenumber}/%{_name}-%{_version}.tar.gz
Source1:        https://www.aquamaniac.de/rdm/attachments/download/%{checksumreleasenumber}/%{_name}-%{_version}.tar.gz.asc
BuildRequires:  doxygen
BuildRequires:  fdupes
# For doc graphs
BuildRequires:  graphviz
BuildRequires:  graphviz-gd
BuildRequires:  libgcrypt-devel >= 1.2.0
BuildRequires:  libopenssl-devel
BuildRequires:  pkgconfig
BuildRequires:  xorg-x11-fonts
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5OpenGL)
BuildRequires:  cmake(Qt5PrintSupport)
BuildRequires:  cmake(Qt5Sql)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5Xml)
BuildRequires:  pkgconfig(gnutls) >= 2.9.8
BuildRequires:  pkgconfig(gtk+-2.0) >= 2.17.5
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.14.0
Recommends:     libgwenhywfar%{libversion}
%if !%{with configure}
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
%endif
%if 0%{?fedora} == 15
BuildRequires:  fox-devel >= 1.6
%else
BuildRequires:  fox16-devel
%endif

%description
Gwenhywfar is a base library used to provide OS abstraction functions
for Linux, FreeBSD, OpenBSD, NetBSD, and Windows. It also includes some
often needed functions (for example, handling and parsing of
configuration files, reading and writingof XML files, and interprocess
communication).

%package tools
Summary:        Tools for the gwenhywfar multi-platform helper library
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/Libraries
Requires:       libgwenhywfar%{libversion} = %{version}

%description tools
Gwenhywfar is a base library used to provide OS abstraction functions
for Linux, FreeBSD, OpenBSD, NetBSD, and Windows. It also includes
some often needed functions (for example, for handling and parsing of
configuration files, reading and writing of XML files, and interprocess
communication).

%package -n libgwenhywfar%{libversion}-plugins
Summary:        Plugins for the gwenhywfar multi-platform helper library
License:        LGPL-2.1-or-later
Group:          System/Libraries
Requires:       %{name} = %{version}

%description -n libgwenhywfar%{libversion}-plugins
Gwenhywfar is a base library used to provide OS abstraction functions
for Linux, FreeBSD, OpenBSD, NetBSD, and Windows. It also includes
some often needed functions (for example, for handling and parsing of
configuration files, reading and writing of XML files, and interprocess
communication).

%package -n libgwenhywfar%{libversion}
Summary:        Multiplatform Helper Library for Other Libraries
License:        LGPL-2.1-or-later
Group:          System/Libraries
Recommends:     %{name}-lang
Recommends:     libgwenhywfar%{libversion}-plugins = %{version}

%description -n libgwenhywfar%{libversion}
Gwenhywfar is a base library used to provide OS abstraction functions
for Linux, FreeBSD, OpenBSD, NetBSD, and Windows. It also includes
some often needed functions (for example, for handling and parsing of
configuration files, reading and writing of XML files, and interprocess
communication).

%package -n libgwengui-cpp%{libversion}
Summary:        C++ interface for Gwenhywfar
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/Libraries

%description -n libgwengui-cpp%{libversion}
This package contains the C++ GUI interface for Gwenhywfar.

%package -n libgwengui-gtk2-%{libversion}
Summary:        GTK+ 2 UI backend for Gwenhywfar
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n libgwengui-gtk2-%{libversion}
Gwenhywfar is a base library used to provide OS abstraction functions
for Linux, FreeBSD, OpenBSD, NetBSD, and Windows. It also includes
some often needed functions (for example, for handling and parsing of
configuration files, reading and writing of XML files, and interprocess
communication).

This package provides the GTK+ 2 implementation of the generic UI toolkit.

%package -n libgwengui-gtk3-%{libversion}
Summary:        GTK+ 3 UI backend for Gwenhywfar
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n libgwengui-gtk3-%{libversion}
Gwenhywfar is a base library used to provide OS abstraction functions
for Linux, FreeBSD, OpenBSD, NetBSD, and Windows. It also includes
some often needed functions (for example, for handling and parsing of
configuration files, reading and writing of XML files, and interprocess
communication).

This package provides the GTK+ 3 implementation of the generic UI toolkit.

%package -n libgwengui-qt5-%{libversion}
Summary:        Qt5 UI backend for the gwenhywfar multi-platform helper library
License:        LGPL-2.1-or-later
Group:          System/Libraries
Provides:       libgwengui-qt4-0 = %{version}
Obsoletes:      libgwengui-qt4-0 < %{version}

%description -n libgwengui-qt5-%{libversion}
Gwenhywfar is a base library used to provide OS abstraction functions
for Linux, FreeBSD, OpenBSD, NetBSD, and Windows. It also includes
some often needed functions (for example, for handling and parsing of
configuration files, reading and writing of XML files, and interprocess
communication).

This package provides the Qt5 implementation of the generic UI toolkit.

%package -n libgwengui-fox16-%{libversion}
Summary:        FOX interface for Gwenhywfar
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/Libraries

%description -n libgwengui-fox16-%{libversion}
This package contains the interface to the FOX toolkit
for Gwenhywfar.

%package devel
Summary:        Header files for the Gwenhywfar multi-platform helper library
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libgwengui-cpp%{libversion} >= %{version}
Requires:       libgwengui-fox16-%{libversion} >= %{version}
Requires:       libgwengui-gtk2-%{libversion} >= %{version}
Requires:       libgwengui-gtk3-%{libversion} >= %{version}
Requires:       libgwengui-qt5-%{libversion} >= %{version}
Requires:       libgwenhywfar%{libversion} = %{version}

%description devel
Gwenhywfar is a base library used to provide OS abstraction functions
for Linux, FreeBSD, OpenBSD, NetBSD, and Windows. It also includes
some often needed functions (e.g. for handling and parsing of
configuration files, reading/writing of XML files, interprocess
communication etc).

%package gwenbuild
Summary:        Specific build system for the aqbanking universe
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}

%description gwenbuild
Gwenbuild is a lightweight and fast build system tailored for the
aqbanking universe.

%lang_package

%prep
%setup -q -n %{_name}-%{_version}

%build
export PATH=%{_libqt5_bindir}:$PATH
# quick fix for $CPP being unset and configure failing to handle include dirs properly
CPP=`which cpp`
export CPP
%if !%{with configure}
autoreconf -ifv
%endif
%configure\
	--enable-release\
	--enable-full-doc\
	--with-docpath=%{_docdir}/%{name}/api \
	--disable-static \
	--with-guis="fox16 qt5 gtk2 gtk3" \
	--with-plugins-cfgmgr=all
%make_jobs
%make_build srcdoc

%install
%make_install
%make_install install-srcdoc
pushd %{buildroot}%{_docdir}/%{name}/api
    # we don't want another 'gwenhywfar' dir below docpath
    mv %{_name}/* ./
    rm -rf %{_name}
    # remove empty files
    `find -maxdepth 1 -type f -empty -print0 | xargs -0 echo rm -f`
popd
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{_name}
%fdupes %{buildroot}%{_datadir}/%{_name}/apidoc
%fdupes %{buildroot}%{_libdir}/cmake
%fdupes %{buildroot}%{_docdir}

%post   -n libgwenhywfar%{libversion} -p /sbin/ldconfig
%postun -n libgwenhywfar%{libversion} -p /sbin/ldconfig
%post   -n libgwengui-cpp%{libversion} -p /sbin/ldconfig
%postun -n libgwengui-cpp%{libversion} -p /sbin/ldconfig
%post   -n libgwengui-gtk2-%{libversion} -p /sbin/ldconfig
%postun -n libgwengui-gtk2-%{libversion} -p /sbin/ldconfig
%post   -n libgwengui-gtk3-%{libversion} -p /sbin/ldconfig
%postun -n libgwengui-gtk3-%{libversion} -p /sbin/ldconfig
%post -n libgwengui-qt5-%{libversion} -p /sbin/ldconfig
%postun -n libgwengui-qt5-%{libversion} -p /sbin/ldconfig
%post -n libgwengui-fox16-%{libversion} -p /sbin/ldconfig
%postun -n libgwengui-fox16-%{libversion} -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS NEWS README TODO
%dir %{_datadir}/%{_name}/
%{_datadir}/%{_name}/dialogs/
%dir %{_libdir}/%{_name}
%dir %{_libdir}/%{_name}/plugins
%dir %{_libdir}/%{_name}/plugins/%{libversion}
%exclude %{_docdir}/%{name}/api

%files tools
%{_bindir}/gct-tool
%{_bindir}/gsa
%{_bindir}/mklistdoc
%{_bindir}/typemaker
%{_bindir}/typemaker2
%{_bindir}/xmlmerge
%{_datadir}/%{_name}/typemaker2/

%files -n libgwenhywfar%{libversion}-plugins
%{_libdir}/%{_name}/plugins/%{libversion}/*

%files -n libgwenhywfar%{libversion}
%{_libdir}/lib%{_name}.so.*

%files -n libgwengui-cpp%{libversion}
%{_libdir}/libgwengui-cpp.so.*

%files -n libgwengui-gtk2-%{libversion}
%{_libdir}/libgwengui-gtk2.so.*

%files -n libgwengui-gtk3-%{libversion}
%{_libdir}/libgwengui-gtk3.so.*

%files -n libgwengui-qt5-%{libversion}
%{_libdir}/libgwengui-qt5.so.*

%files -n libgwengui-fox16-%{libversion}
%{_libdir}/libgwengui-fox16.so.*

%files devel
%{_bindir}/%{_name}-config
%dir %{_datadir}/aclocal
%{_datadir}/aclocal/%{_name}.m4
%doc %{_docdir}/%{name}/api/
%{_includedir}/%{_name}%{devversion}/
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{_name}.pc
%{_libdir}/pkgconfig/gwengui-gtk2.pc
%{_libdir}/pkgconfig/gwengui-gtk3.pc
%{_libdir}/pkgconfig/gwengui-qt5.pc
%{_libdir}/pkgconfig/gwengui-fox16.pc
%dir %{_libdir}/cmake
%{_libdir}/cmake/%{_name}-%{devrelease}
%{_libdir}/cmake/gwengui-cpp-%{devrelease}
%{_libdir}/cmake/gwengui-qt5-%{devrelease}

%files lang -f %{_name}.lang

%files gwenbuild
%dir %{_datadir}/gwenhywfar
%{_datadir}/gwenhywfar/gwenbuild
%{_datadir}/gwenbuild
%{_bindir}/gwbuild

%changelog
* Thu Jan 23 2025 Ralf Habacker <ralf.habacker@freenet.de>
- Add missing runtime dependency for libgwengui-cpp to
  the development package
* Wed Jan  1 2025 Nico Kruber <nico.kruber@gmail.com>
- Update to 5.12.0
  + Add GWEN_MSG convenience functions
  + Use pkgconf for gpg-error build flags
  + Bugfixes
* Sun Nov 24 2024 Nico Kruber <nico.kruber@gmail.com>
- Update to 5.11.2 (beta)
- Changelog for 5.11.0 (beta)
  + first version with support for HKTAN#7 and first implementation
    of "Decoupled TAN" for app-based TAN input
* Tue Oct 18 2022 Jason Sikes <jsikes@suse.com>
- Update to 5.10.0
  * Bugfixes
  * Added more checks for invalid dates
  * Remove GTK2 from target "mp"
  * Make output a bit more compact.
* Sun Mar 20 2022 Johannes Engel <jcnengel@gmail.com>
- Update to 5.9.0
  + Bugfixes
* Fri Feb 11 2022 Johannes Engel <jcnengel@gmail.com>
- Update to 5.8.2
  + GUI support for keypress/keyrelease events
  + Return Window handle under X11
  + Bugfixes
* Mon Dec 13 2021 Johannes Engel <jcnengel@gmail.com>
- Update to 5.7.4
  + Bugfixes
* Tue Sep 21 2021 Johannes Engel <jcnengel@gmail.com>
- Update to 5.7.2
  + Bugfixes
* Tue Sep 14 2021 Johannes Engel <jcnengel@gmail.com>
- Update to 5.7.1
  + Bugfixes
  + Small improvements
* Wed Mar  3 2021 Johannes Engel <jcnengel@gmail.com>
- Update to 5.6.0
  + Bugfixes
  + Small improvements
* Sat Oct 31 2020 Johannes Engel <jcnengel@gmail.com>
- Update to 5.4.1
  + Streamline openSSL integration
* Tue Aug 18 2020 Dirk Mueller <dmueller@suse.com>
- replace tarball with upstream one so that download_files verfication
  passes
* Wed Jul 29 2020 Johannes Engel <jcnengel@gmail.com>
- Update to 5.4.0
  + Introduce more generic approach to XML using libxml2
  + Straighten Qt dependencies
  + Bugfixes
* Wed Apr  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.3.0. No changelog.
* Sat Mar 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.2.0. No changelog.
* Thu Jan 23 2020 Wolfgang Bauer <wbauer@tmo.at>
- Update to 5.1.2
  + XML: Improved format of written XML documents, simplified code.
  + DB: Fixed a bug in GWEN_DB_WriteVarValueToBuffer()
    Was not handling "name" as full path.
  + Fixed a bug (created files had no file access rights: #178).
* Fri Jan 17 2020 Christophe Giboudeaux <christophe@krop.fr>
- Temporarily change the source URL until the tag is sync'ed to the github mirror.
* Wed Jan 15 2020 Johannes Engel <jcnengel@gmail.com>
- Update to 5.1.1
  + Bugfixes
* Wed Nov 27 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Redownload tarball via osc service, upstream source have changed.
* Mon Nov 11 2019 Nico Kruber <nico.kruber@gmail.com>
- Update to 4.99.25rc9
  + fixed crashes on Windows
  + minor tweaks
* Mon Oct 14 2019 Nico Kruber <nico.kruber@gmail.com>
- Update to 4.99.22rc6
* Sat Sep 28 2019 Johannes Engel <jcnengel@gmail.com>
- Update to 4.99.19rc3
  + Merge with gwenhywfar package
* Tue Sep 24 2019 Nico Kruber <nico.kruber@gmail.com>
- Update to 4.99.17rc1
* Sat Sep 14 2019 Johannes Engel <jcnengel@gmail.com>
- Update to 4.99.15
  + Fix issue with Postbank
* Tue Apr 23 2019 Michele Bologna <michele.bologna@suse.com>
- Fixed typo in changelog file
* Tue Apr 23 2019 Jan Engelhardt <jengelh@inai.de>
- Remove --with-pic which has no effect with --disable-static.
- Redo summaries without em dashes.
* Mon Mar 25 2019 Christophe Giboudeaux <christophe@krop.fr>
- Prepare the KDE4/Qt4 removal from factory.
- Run spec-cleaner
* Wed Jan 30 2019 sbrabec@suse.com
- Update to version 4.99.8 (beta) required by libchipcard-5.1.2:
  * Generalization in the generic TLV to GWEN DB parser.
  * Speedup of GWEN_Date_dup (about factor 16).
  * Correctly read a UTF-8-encoded MT940 file.
  * Updated Gwengui-Gtk3.
  * API improvements.
  * Other fixes.
* Tue May 15 2018 dimstar@opensuse.org
- Update to version 4.20.1:
  + bgo#794707: Aqbanking combo boxes missing selection.
  + Major speedup of GWEN_IdList64_AddId().
  + Fix all Gtk3 deprecation warnings.
* Thu Apr  5 2018 luc14n0@linuxmail.org
- Update to version 4.20.0:
  + Add a Gtk3 frontend.
- Add:
  + pkgconfig(gtk+-3.0) BuildRequires and libgwengui-gtk3
    subpackage following upstream changes.
  + Conditionalized autoconf, automake and libtool BuildRequires
    along with autoreconf call to ease the switching between
    tarballs with or without configure script.
  + Missing ldconfig post/postun scriptlets for libgwengui-qt5.
- Drop standard BuilRoot tag definition: RPM already handles this
  itself.
- Delete redundant deprecated clean section.
- Switch gnutls and gtk2 devel packages BuildRequires with their
  respectives pkgconfig modules counterparts.
* Mon Dec 11 2017 wbauer@tmo.at
- Re-enable Qt4 front-end, kmymoney still needs it for its kbanking
  plugin
- BuildIgnore libopenssl-1_0_0-devel to avoid openssl conflict on
  Tumbleweed
* Mon Dec  4 2017 nico.kruber@gmail.com
- Update to 4.18.0
  + show SSL certificate hashes as MD5, SHA1, and SHA512
* Mon Nov 27 2017 dimstar@opensuse.org
- Conditionalize usage of qt4 libs
* Sat Jun 10 2017 wbauer@tmo.at
- Enable Qt5 front-end
* Tue May 30 2017 nico.kruber@gmail.com
- Update to 4.17.0
  + minor bugfixes
* Fri Oct 14 2016 jcnengel@gmail.com
- Update to 4.16.0
  + Fix issues handling certificates
* Wed Sep  7 2016 nico.kruber@gmail.com
- quick fix for $CPP being unset and configure failing to handle
  include dirs properly
* Sun Aug 21 2016 jcnengel@gmail.com
- Update to 4.15.5beta
  + Fix connections to buggy SSL servers
* Sat Apr 30 2016 nico.kruber@gmail.com
- Update to 4.15.3
  + improve and simplify the TLS code
  + fix an error in the message parser (MsgEngine) that caused
    problems with some special HBCI messages
  + new (experimental) QT5 front-end (not enabled yet here)
* Wed Jan 13 2016 jcnengel@gmail.com
- Update to 4.15.2beta
  + Use new code for SSL connections to enable build with current
    GnuTLS versions. This obsoletes patch gwenhywfar-gnutls30.patch
* Thu Nov  5 2015 nico.kruber@gmail.com
- Update to 4.14.0:
  + Fix segfault on windows when using HBCI with keyfile.
  + Major speedup of GWEN_Directory_GetMatchingFilesRecursively().
  + Re-work Compiler Symbol Visibility Check.
  + Drop unused autoconf variable gwen_enable_export.
  + Fix symbol visibilty check for GCC 5.x.
  + Revert "Turn compiler warning for implicit function declaration
    into error."
  + Revert "Disable timestamps in HTML pages generated by Doxygen".
  + Disable timestamps in HTML pages generated by Doxygen.
  + typemaker2: Added support for _free-hooks, fixed many compiler
    warnings.
  + API ADDITION: Added 2 more virtual functions to
    GWEN_MULTICACHE.
  + Added functions
    GWEN_Param_List_Get/SetCurrentValueAsInt/Double.
* Thu Apr 23 2015 zaitor@opensuse.org
- Add gwenhywfar-gnutls30.patch: Fix build with gnutls30, patch
  taken from Arch linux.
* Fri Jan 30 2015 zaitor@opensuse.org
- Update to version 4.13.1:
  + Add function declaration that was missing in header, as
    discovered by the additional compiler option.
  + Turn compiler warning for implicit function declaration into
    error.
  + Fix function name for systems without <langinfo.h> but with
    <localcharset.h>.
* Sat Jan  3 2015 jcnengel@gmail.com
- Update to version 4.13.0
  + Some bugfixes, stable version
* Fri Apr 18 2014 jcnengel@gmail.com
- Update to version 4.12.0beta
  + Fixes a bug in calculating quarter's beginning and end
* Mon Mar  3 2014 jcnengel@gmail.com
- Update to version 4.11.0beta
  + Bugfixes by Elias Oltmanns
* Sun Feb  9 2014 jcnengel@gmail.com
- Update to version 4.10.0beta
  + Add functions for individual plugin paths for other libraries
- Create Fox16 GUI
- Move documentation to separate package to enable multi-version
  coexistence of the library
* Mon Jan  6 2014 nico.kruber@gmail.com
- Update to version 4.9.0beta:
  + adds new code for cipher selection with SSL connections
    (still some problems with the Netbank, please report back)
  + Netbank works setting the GWEN_TLS_CIPHER_PRIORITIES
    environment variable to "NORMAL:-AES-256-CBC"
* Wed Oct 23 2013 nico.kruber@gmail.com
- Update to version 4.8.0beta:
  + new functions to work with dates (module GWEN_DATE,
    e.g.  GWEN_Date_GetLastHalfYearStart())
  + fix some errors in the layout of the  FOX 1.6 GUI module.
  + some improvements in typemaker2.
* Wed Aug 21 2013 nico.kruber@gmail.com
- Update to version 4.7.0beta:
  + contains improvements if the TypeMaker2 tool
  + fixes an error linking libgpg-error.so
  + adds some functions to the GWEN_XML and GWEN_DATE modules
    used by the new AqBanking version 5.0.31beta
  + Info: this is still beta because the MULTICACHE module is
    still work in progress
* Sun Jun 23 2013 nico.kruber@gmail.com
- Update to version 4.6.0beta:
  + adds a new module for cache handling and some widely used
    functionality
  + major (internal) improvements to typemaker2
  + complete German translation (thanks to Christian)
- Update to version 4.5.0beta:
  + adds some small changes for SEPA transactions needed by
    aqbanking
* Sat Mar  2 2013 coolo@suse.com
- update license to new format
* Tue Jul  3 2012 aj@suse.de
- Change lang package Requires to Recommends since it is not
  mandatory at runtime.
* Wed May  9 2012 Nico.Laus.2001@gmx.de
- Update to version 4.3.3:
  + do not use the deprecated libgcrypt interface for RSA keys
    anymore (allows compilation with newer libgcrypt versions)
* Fri Mar  9 2012 Nico.Laus.2001@gmx.de
- Update to version 4.3.2:
  + fixes network problems on Windows
* Mon Jan  2 2012 Nico.Laus.2001@gmx.de
- included %%{_datadir}/aclocal in the devel package
* Tue Dec 20 2011 Nico.Laus.2001@gmx.de
- removed gwenhywfar-gnutls-3.0.3.patch (fixed upstream in 4.3.1)
* Mon Dec 19 2011 Nico.Laus.2001@gmx.de
- Update to version 4.3.1:
  + this version is needed for AqBanking's new support for the
    optical chipTAN method
  + some improvements to the typemaker2 tool
* Wed Sep 28 2011 vuntz@opensuse.org
- Add gwenhywfar-gnutls-3.0.3.patch: fix build with gnutls 3.0.3.
* Wed Sep 21 2011 kruber@zib.de
- Update to version 4.3.0:
  + added a new method for converting charsets
  + better error handling in the build system
* Fri Aug 12 2011 dimstar@opensuse.org
- Add GPL-2.0+ tag to the main package and the tools subpackage, as
  this is the correct license for the tools and related sources.
  See also bnc#710065.
* Tue Aug  2 2011 dimstar@opensuse.org
- Update to version 4.2.1:
  + Make QLabel in GUI wrap words.
  + Relaxed http code.
* Sat Jul 16 2011 malcolmlewis@opensuse.org
- Update to version 4.2.0:
  + Marked argument list of GWEN_StringList_new() as void.
  + Added keyword "void" to functions with empty argument list.
  + Let typemaker tools use "void" for empty argument lists in
    constructors.
  + Added field "CustomerId" to GWEN_Crypt_Token_Context.
  + Added function GWEN_DB_GetParentGroup().
  + Added line for "hasKeyNumber" flag.
  + Show customer if available.
  + Added some tm2 files to ignore list.
  + typemaker2: added type uint64_t.
  + Improved and fixed GWEN_TLV, added functions
    GWEN_TLV_ReadHeader() and GWEN_TLV_WriteHeader().
  + Started working on a simple archiver.
  + Fixed a few bugs in new TLV code.
  + Added tool "gsa" ("Gwen's simple archiver").
  + Improved HTTP handling:
  - added function GWEN_SyncIo_Http_RecvBodyToSio().
  - added function GWEN_HttpSession_RecvPacketToFile().
  + Added function GWEN_Directory_GetAbsoluteFolderPath().
  + Added convenience function GWEN_Sar_UnpackArchive().
  + Added code and commands to sign a sar archive.
  + Improved progress handling in network code.
  + Fixed GWEN_MDigest__HashFileTree().
  + Added missing include.
  + Various bug fixes and code cleanup.
- Update Url as Gwenhywfar is now being hosted at
  http://www.aqbanking.de/.
- Update spec file License field from LGPLv2.1+ to LGPL-2.1+ to
  conform with spdx.org identifier.
- Minor reformatting in spec file.
- Remove service usage, following the new consensus on Factory
  packaging.
* Sat Jun 11 2011 Nico.Laus.2001@gmx.de
- Update to version 4.1.0:
  + new code for sorting any GWEN_LIST
  + some bug fixes
* Thu Mar 17 2011 Nico.Laus.2001@gmx.de
- Update to version 4.0.9:
  + fixes a bug in the Qt4 frontend
  + fixes a bug in the LIST1 module
  + fixes xml file generation using the XMLDB module
* Sun Feb 20 2011 Nico.Laus.2001@gmx.de
- Update to version 4.0.7:
  + fixes problems with smsTAN/mTAN
  + keep the focus chain intact in QT4 GUI
- Update to version 4.0.5:
  + fixes a bug with chunked HTTP
* Thu Jan 27 2011 Nico.Laus.2001@gmx.de
- Update to version 4.0.4:
  + fixes a bug in the GTK2 front-end
  + fixes a bug in the network code on MaxOSX
* Sat Jan 15 2011 Nico.Laus.2001@gmx.de
- Update to version 4.0.3:
  + improved error messages
  + several bug fixes
* Fri Dec 10 2010 vuntz@opensuse.org
- Update to version 4.0.2:
  + Fix GTK+ password entry.
  + Build fixes.
- Split libgwengui_gtk2-0 and libgwengui_qt4-0 subpackages, as we
  don't want libgwenhywfar60 to depend on both GTK+ and Qt.
- Add libgwengui-gtk2-0 and libgwengui-qt4-0 Requires to devel
  package.
* Thu Sep  2 2010 dimstar@opensuse.org
- Update to version 4.0.1:
  + Fix gtk2 building for Windows
  + Improved HTTP handling.
* Thu Sep  2 2010 dimstar@opensuse.org
- Update to version 4.0.0:
  + Gwenhywfar4 features a new XML-based platform and toolkit.
  + Independent dialog framework which is heavily used by
    AqBanking5.
  + Provide generic UI implementations for GTK-2, Qt-4, and
    FOX-1.6.
  + The network code has been rewritten and thereby changed from
    asynchronous to synchronous access to fix some strange timeout
    problems.
  + Many bugs and problems have been fixed.
- Add gtk2-devel and libqt4-devel BuildRequires.
- Follow the so bump of the library, change the library package
  name to from libgwenhywfar47 to libgwenhywfar60
- Remove Provides/Obsoletes of gwenhywfar$sover from
  libgwenhywfar$sover-plugins: it was there for upgrades of the old
  package.
- Pass --with-qt4-libs=%%{_libdir} to configure.
- Use _smp_mflags.
* Sat Jan  2 2010 vuntz@opensuse.org
- Update to version 3.11.3:
  + GWEN_DB: Escape and unescape group names upon read/write,
    respectively.
  + Show a more informative erro message when a false chipcard has
    been inserted.
- Changes from version 3.11.2:
  + Add unittest for GWEN_Url_fromString that checks those cases
    that work.
  + Do not abort on unknown port number.
  + Improve error messages.
  + Check for NULL token name before crashing in FSLock_new so that
    a more clear error message is printed instead.
  + Decrease debug level of non-critical info message.
  + Improved handling of file/directory locks on POSIX systems.
  + Windows fixes.
  + Build system fixes.
* Tue Dec 15 2009 vuntz@opensuse.org
- Remove unneeded libxml2-devel BuildRequires.
- Remove autoreconf call since we have no patch.
- Rework the install section to be more readable.
- Rename gwenhywfar47 to libgwenhywfar47-plugins, since it's a more
  appropriate name. Add Provides/Obsoletes for the old package.
- Make libgwenhywfar47 recommends the libgwenhywfar47-plugins
  package. Also remove any Requires/Recommends from the main
  package to libgwenhywfar47-plugins or gwenhywfar47 since
  libgwenhywfar47 should be enough.
- Rename the main package to gwenhywfar-tools and move some tools
  from devel subpackage there.
- Split a lang package, that is required by the library package,
  and make the library package now provide gwenhywfar to make the
  lang package installable.
* Tue Dec  1 2009 Nico.Laus.2001@gmx.de
- Update to version 3.11.1:
  + compile on windows
- Changes from version 3.11.0:
  + fixes some minor bugs
  + extended the HTTP session module to allow testing connections
    (used by the AqBanking-EBICS module to download new
    certificates)
  + special support for statistical modules has been removed again
    to simplify the build system
- Changes from version 3.10.1:
  + fixes a bug in GWEN_Url_fromString() and supports username and
    password with HTTP proxies (tested with squid2)
  + fixed a problem on MacOSX
- Changes from version 3.10.0
  + adds new support for RDH-10
  + includes the tool typemaker2, an improved version of the old
    typemaker which includes support for AqFinance
  + added the data type GWEN_DATE which is now used by AqFinance
    instead of GWEN_TIME when only a date is required instead of a
    full timestamp
* Mon Oct 12 2009 crrodriguez@opensuse.org
- fix dependencies (was using >= instead of =)
* Thu Sep  3 2009 sbrabec@suse.cz
- Typo fix in dependencies.
* Fri Aug 14 2009 sbrabec@suse.cz
- Split package to allow parrallel installation of more versions.
* Wed Jun 24 2009 mkudlvasr@suse.cz
- update to version 3.8.3
  * lots of bugs fixed, lots of new features
- removed patch0 (tests/gwenhywfar.c). not needed anymore
* Thu Jan 24 2008 coolo@suse.de
- fixing open call
* Fri Nov  9 2007 crrodriguez@suse.de
- update to version 2.6.2
  * Release is only interesting for windows or NetBSD users
- disable static libraries
- remove "la" files
- remove unnedded dependency on libopenssl-devel in the -devel package
* Fri Jul 27 2007 sbrabec@suse.cz
- Updated to version 2.6.1:
  * Minor bugs have been fixed.
  * Cross-compiling is now supported.
  * Some missing list functions have been added.
  * Decreases the verbosity.
  * Makes gwenhywfar completely relocatable using binreloc.
- Split package according to shared library packaging policy.
- Build with libxml2.
- Build and create api docs.
* Mon Oct  2 2006 sbrabec@suse.cz
- Updated to version 2.4.1:
  * bug fixes
  * removed debugging messages
  * clean up the API
* Fri Sep 15 2006 jhargadon@suse.de
- update to version 2.4.0
- This release adds GWEN_DBIO plugin which writes GWEN_DB's as XML files
* Tue Jun 20 2006 stbinner@suse.de
- Update to version 2.3.0:
  * Adds a new module for fast lookup of objects via integer IDs.
  * Adds a storage module to be used by further projects.
* Thu May 11 2006 sbrabec@suse.cz
- Updated to version 2.2.0.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 sbrabec@suse.cz
- Updated to version 1.19.2.
* Wed Oct 19 2005 sbrabec@suse.cz
- New SuSE package, version 1.18.0.
  Based on spec file from Rajesh Singh <rajeshsingh.geo@yahoo.com>.
